/* config.h.  Generated manually for Windows. */

/* Define if your libmikmod has MikMod_free (not found in <= 3.2.0-beta2). */
#define HAVE_MIKMOD_FREE

/* Define the directory for shared data. */
#undef PACKAGE_DATA_DIR

/* Define to 1 if you have the <fcntl.h> header file. */
#define HAVE_FCNTL_H

/* Define to 1 if you have the <limits.h> header file. */
#define HAVE_LIMITS_H

/* Define to 1 if you have the `snprintf' function. */
#undef HAVE_SNPRINTF /* but we do define HAVE_VSNPRINTF */

/* Define to 1 if you have the `srandom' function. */
/* #undef HAVE_SRANDOM */

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H

/* Define to 1 if you have the `vsnprintf' function. */
#define HAVE_VSNPRINTF
